/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: AttributeMapping.java 1891 2007-10-09 15:04:03Z loris $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.xmlconfig.mapping;

/**
 * Defines a mapping for attributes of a class.
 * @author Florent Benoit
 */
public class AttributeMapping extends AbsMapping {

    /**
     * Value of this element has to be used (this is not an xml attribute).<br>
     * Default is false.
     */
    private boolean isElement = false;

    /**
     * Element should be used as a List.
     */
    private boolean isListElement = false;

    /**
     * Getter to use.
     */
    private String getter = null;

    /**
     * Setter to use.
     */
    private String setter = null;


    /**
     * This attribute is mapped to an XML element ?
     */
    public void setElement() {
        this.isElement = true;
    }

    /**
     * Is that this attribute is mapped to an XML element ?
     * @return true if it the case
     */
    public boolean isElement() {
        return this.isElement;
    }

    /**
     * This attribute is considered as a List.
     */
    public void setListElement() {
        this.isListElement = true;
    }

    /**
     * Is that this attribute should be considered as a list ?
     * @return true if it the case
     */
    public boolean isListElement() {
        return this.isListElement;
    }

    /**
     * @return the getter for this attribute.
     */
    public String getGetter() {
        return getter;
    }

    /**
     * Sets the getter for this attribute.
     * @param getter the given getter name
     */
    public void setGetter(final String getter) {
        this.getter = getter;
    }

    /**
     * @return the setter for this attribute.
     */
    public String getSetter() {
        return setter;
    }

    /**
     * Sets the setter for this attribute.
     * @param setter the given setter name
     */
    public void setSetter(final String setter) {
        this.setter = setter;
    }

    /**
     * Returns a string representation of the object.
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));
        sb.append("[");
        sb.append(super.toString());
        if (isElement) {
            sb.append(", isElement=");
            sb.append(isElement);
        }
        if (isListElement) {
            sb.append(", isListElement=");
            sb.append(isListElement);
        }
        sb.append("]");

        return sb.toString();
    }

}
